#version 130

precision mediump float;

uniform vec3 light_position;
uniform vec4 light_color;
uniform vec4 ambient_color;
uniform sampler2D terrainTextureStandard;
uniform sampler2D terrainTextureDirt;
uniform sampler2D shadowMap;
uniform float isShadowOn;

in vec4 frag_color;
in vec4 shadowCoord;
in vec2 texCoord0;
in vec3 world_normal;
in vec4 world_position;

out vec4 fragColor;

void main()
{	
	float shadow = 1.0;
	
	if(isShadowOn > 0.0)	{
		if(shadowCoord.w > 0.0)	{
			vec4 shadowCoordinate = shadowCoord/shadowCoord.w;
	
			shadowCoordinate.z += 0.0001;
	
			float distanceFromLight = texture2D(shadowMap, shadowCoordinate.st).z;

			shadow = distanceFromLight < shadowCoordinate.z ? 0.5 : 1.0;
		}
	}

	vec3 normal = normalize(world_normal);

	vec3 position = world_position.xyz/world_position.w;
    
	vec3 light_dir = normalize(light_position - position);

	vec4 ambient = ambient_color * frag_color;

	vec4 diffuse = frag_color * light_color * max(0.0, dot(normal, light_dir));
    
	fragColor = (ambient + diffuse) * shadow;

	fragColor = fragColor * texture(terrainTextureStandard, texCoord0.st);
}